@@ -1,4 +1,4 @@
-library(geostatsp)
+library('geostatsp')
 matrix(NNmat(7, 7)[,25], 7, 7)
 
 myr = raster(extent(0,600,0,300), nrows=30,ncols=60)
